FeroConfig class

Constructors

FeroConfig()
factory

Properties

apiBaseUrl String
getter/setter pair
env Environment
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
socketHost String
getter/setter pair
socketPort int?
getter/setter pair
useHttps bool
getter/setter pair

Methods

initialize({required Environment environment}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited