ConflictResolutionStrategy enum

Defines how to resolve conflicts when both local and remote have changes.

Inheritance
Available extensions

Values

serverWins → const ConflictResolutionStrategy

Remote (server) changes always win. Local changes are discarded.

clientWins → const ConflictResolutionStrategy

Local (client) changes always win. Remote changes are discarded.

mergeBoth → const ConflictResolutionStrategy

Both local and remote changes are applied (merge both).

highestVersionWins → const ConflictResolutionStrategy

Version-based resolution: higher version wins (Fero server is source of truth). If versions are equal, server wins.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ConflictResolutionStrategy>
A constant List of the values in this enum, in order of their declaration.