getInitialSyncCheckpoint abstract method
Returns the last checkpoint from the initial sync process for featureKey.
Implementation
Future<SyncCheckpoint?> getInitialSyncCheckpoint(String featureKey);
Returns the last checkpoint from the initial sync process for featureKey.
Future<SyncCheckpoint?> getInitialSyncCheckpoint(String featureKey);