updateInitialSyncCheckpoint abstract method

Future<void> updateInitialSyncCheckpoint(
  1. String featureKey,
  2. SyncCheckpoint? checkpoint
)

Updates the last checkpoint used by the initial sync process for featureKey. This is kept separate from the background sync checkpoint to avoid conflicts.

Implementation

Future<void> updateInitialSyncCheckpoint(
  String featureKey,
  SyncCheckpoint? checkpoint,
);