getLocallyModified abstract method

Future<List<SyncPayload<LocalItem>>> getLocallyModified({
  1. int batchSize = 50,
})

Fetch locally modified items that need to be synced Returns items that have changed locally and need to be pushed to server

Implementation

Future<List<SyncPayload<LocalItem>>> getLocallyModified({
  int batchSize = 50,
});