getLocallyModifiedByIds abstract method

Future<List<SyncPayload<LocalItem>>> getLocallyModifiedByIds({
  1. required List<String> ids,
})

Fetch locally modified items that need to be synced Returns items that have changed locally and need to be pushed to server

Implementation

Future<List<SyncPayload<LocalItem>>> getLocallyModifiedByIds({
  required List<String> ids,
});