updateInitialSyncCheckpoint abstract method
Updates the last checkpoint used by the initial sync process for featureKey.
This is kept separate from the background sync checkpoint to avoid conflicts.
Implementation
Future<void> updateInitialSyncCheckpoint(
String featureKey,
SyncCheckpoint? checkpoint,
);