getLocallyModifiedByIds abstract method
Fetch locally modified items that need to be synced Returns items that have changed locally and need to be pushed to server
Implementation
Future<List<SyncPayload<LocalItem>>> getLocallyModifiedByIds({
required List<String> ids,
});