FeatureSyncStatus class
Constructors
- FeatureSyncStatus({required String featureKey})
Properties
-
errorNotifier
→ ValueNotifier<
String?> -
final
- featureKey → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
statusNotifier
→ ValueNotifier<
SyncProcessStatus> -
final
Methods
-
complete(
) → void -
fail(
String error) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited