InitialSyncManager class
Event-driven initial sync manager.
Listens to InitialSyncRequiredEvent from Fero server and orchestrates sync.
Automatically handles log storage and conflict tracking.
- Implemented types
Constructors
-
InitialSyncManager({required Map<
String, FeatureInitialSyncConfig> featureConfigs, RetryPolicy? retryPolicy, int maxRetries = 5, required int batchSize, required int maxBatchSize, required SyncMetaDataRepo metaRepo})
Properties
- batchSize → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxBatchSize → int
-
final
- metaRepo → SyncMetaDataRepo
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
statusNotifier
→ ValueNotifier<
InitialSyncStatus> -
final
Methods
-
cancel(
) → void -
Cancel ongoing initial sync operation.
override
-
dispose(
) → void -
Dispose and cleanup resources.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
) → Future< void> -
Run initial sync for all handlers.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited